class FBCommentsPlugin {
	constructor (API, name, config) {
		this.API = API;
		this.name = name;
		this.config = config;
	}

	addInsertions () {
		this.API.addInsertion('customCommentsCode', this.addPostScripts, 1, this);
	}

	addPostScripts (rendererInstance, context) {
		let url = '';
		let previewNotice = '';
		let scriptToLoad = '';
		let cookieBannerGroup = 'text/javascript';
		let consentScriptToLoad = '';
		let consentNotice = '';
		let cssHeaderClass = ` class="${this.config.cssHeaderClass}"`;
		let cssWrapperClass = ` class="${this.config.cssWrapperClass}"`;
		let cssInnerWrapperClass = ` class="${this.config.cssInnerWrapperClass}"`;

		if (!this.config.cssHeaderClass) {
			cssHeaderClass = '';
		}

		if (!this.config.cssWrapperClass) {
			cssWrapperClass = '';
		}

		if (!this.config.cssInnerWrapperClass) {
			cssInnerWrapperClass = '';
		}

		if (rendererInstance.globalContext && rendererInstance.globalContext.website) {
			url = rendererInstance.globalContext.website.pageUrl;
		}

		let heading = `
			<h${this.config.headingLevel}${cssHeaderClass}>
		        ${this.config.textHeader}
		    </h${this.config.headingLevel}>
	    `;

	    if (!this.config.textHeader) {
	    	heading = '';
	    }

	    if (this.config.cookieBannerIntegration) {
			cookieBannerGroup = 'gdpr-blocker/' + this.config.cookieBannerGroup.trim();
			consentScriptToLoad = `
			<script type="text/javascript">
				document.body.addEventListener('publii-cookie-banner-unblock-${this.config.cookieBannerGroup.trim()}', function () {
					document.getElementById('fbcomments-no-consent-info').style.display = 'none';
				}, false);
			</script>`;
			consentNotice = `<div
				data-gdpr-group="${cookieBannerGroup}"
				id="fbcomments-no-consent-info" 
				style="background: #f0f0f0; border: 1px solid #ccc; border-radius: 5px; color: #666; display: block; margin-top: 10px; padding: 10px; text-align: center; width: 100%;">
				${this.config.cookieBannerNoConsentText}
			</div>`;
		}

	    if (rendererInstance.previewMode) {
	    	previewNotice = `<div style="background: #f0f0f0; border: 1px solid #ccc; border-radius: 5px; color: #666; display: block; padding: 10px; text-align: center; width: 100%;">FB Comments are not working in the preview mode.</div>`;
	    }

		if (!rendererInstance.previewMode) {
			scriptToLoad = `
				<div id="fb-root"></div>
				<script 
					type="${cookieBannerGroup}"
					async 
					defer 
					crossorigin="anonymous" 
					src="https://connect.facebook.net/${this.config.language}/sdk.js#xfbml=1&version=v12.0">
					nonce="${this.config.nonce}"
				</script>	
			`;
		}

		return `
			<div${cssWrapperClass}>
	            <div${cssInnerWrapperClass}>
	               	${heading}
	               	${previewNotice}
					<div 
						class="fb-comments" 
						data-href="${url}"
						data-width="${this.config.width}"
						data-colorscheme="${this.config.colorScheme}"
						data-lazy="${this.config.lazyload}"
						data-order-by="${this.config.orderBy}"
						data-numposts="${this.config.numberOfComments}"></div>
					<noscript>${this.config.textFallback}</noscript>
					${consentNotice}
				</div>
			</div>
			${scriptToLoad}
			${consentScriptToLoad}
    	`;
	}
}

module.exports = FBCommentsPlugin;